@@ -16,11 +16,13 @@ class SalaryFrequency(StrEnum):
     WEEK = "week"
     HOUR = "hour"
 
+
 class RemoteType(StrEnum):
     ONSITE = "onsite"
     HYBRID = "hybrid"
     REMOTE = "remote"
 
+
 class SourceType(StrEnum):
     ATS = "ats"
     CUSTOM_FILE = "custom-file"
@@ -39,11 +41,12 @@ class Feed(VacanciesOrganizationModel, table=True):
     status: str = Field(index=True)
     file_url: Optional[str] = Field()
     ats_link_id: Optional[UUID] = Field()
+    entrypoint: Optional[str] = Field()
     last_sync_date: Optional[datetime] = Field()
     source_type: SourceType =  Field(sa_column=Column(Enum(SourceType)))
     synced_vacancy_count: int = Field(default=0)
-    mapping: dict = Field(sa_column=Column(JSON))
-    custom_fields: dict = Field(sa_column=Column(JSON))
+    mapping: list = Field(sa_column=Column(JSON))
+    custom_fields: list = Field(sa_column=Column(JSON))
 
 
 class Vacancy(VacanciesOrganizationModel, table=True):
@@ -63,18 +66,20 @@ class Vacancy(VacanciesOrganizationModel, table=True):
     category: List[str] = Field(sa_column=Column(JSON))
     experience: List[str] = Field(sa_column=Column(JSON))
     education: List[str] = Field(sa_column=Column(JSON))
-    hours_fte: Optional[float] = Field(default=1.0)
-    hours_min: Optional[int] = Field(default=1)
-    hours_max: Optional[int] = Field(default=40)
+    hours_fte: Optional[float] = Field()
+    hours_min: Optional[int] = Field()
+    hours_max: Optional[int] = Field()
     location_address: Optional[str] = Field()
     location_zipcode: Optional[str] = Field()
     location_city: Optional[str] = Field()
     location_state: Optional[str] = Field()
     location_country: Optional[str] = Field()
+    location_lat: Optional[float] = Field()
+    location_lng: Optional[float] = Field()
     salary_min: Optional[float] = Field()
     salary_max: Optional[float] = Field()
-    salary_currency: str = Field(default="EUR")
-    salary_frequency: SalaryFrequency = Field(sa_column=Column(Enum(SalaryFrequency)))
+    salary_currency: Optional[str] = Field()
+    salary_frequency: Optional[SalaryFrequency] = Field(sa_column=Column(Enum(SalaryFrequency)))
     recruiter_first_name: Optional[str] = Field()
     recruiter_last_name: Optional[str] = Field()
     recruiter_phone_number: Optional[str] = Field()
